#!/usr/bin/perl
## ######### PROJECT NAME : ##########
## 
## Lib_Modules.pm for wishmin
## 
## ######### PROJECT DESCRIPTION : ###
## 
## This library provides helper to use modules.
## 
## ###################################
## 
## Made by Boutonnet Alexandre
## Email   <aboutonnet@intellique.com>
## 
## Started on  Tue May 19 16:46:58 2009 Boutonnet Alexandre
## Last update Wed May 27 15:55:24 2009 Boutonnet Alexandre
## 
## ###################################
##

package Lib_Modules;

use Data::Dumper;

my $MOD_DIR = "modules/";
my $INFO_FILE = "module.info";
my $RIGHT_FILE = "etc/wishmin.rules";

# This function returns a big hash like
#   'Shares' => {
#                  'desc' => 'Shares Configuration',
#                  'path' => 'modules/Shares',
#                  'entry_point' => 'index.pl',
#                },
sub list_modules
{
    my $ret_hash = {};

    # get modules directory listing
    opendir(DIR, $MOD_DIR) || return (1, "Unable to open $MOD_DIR : $!");
    my @file_list = grep { /^[^\.]/ } readdir(DIR);
    closedir(DIR);

    foreach my $file (@file_list)
    {
	my $file_path = $MOD_DIR.$file;

	# Ignoring files different from a directory
	next if (! -d $file_path || (-l $file_path && -d readlink($file_path)));

	#I test if I can read the config file of each module
	next if (! -f $file_path."/".$INFO_FILE || ! -r $file_path."/".$INFO_FILE);

	my ($log_ret, $log_instance) = Lib_Log::get_obj_instance();
	Lib_CGI::send_critical_header($log_instance) if ($log_ret);
	
 	my ($ret_code, $conf_instance) = new INTLIQ::Conf($file_path."/".$INFO_FILE, $log_instance);
	Lib_CGI::send_critical_header($conf_instance) if ($ret_code);

	my $null;
	# verifying desc info
	($ret_code, $null) = $conf_instance->get_value("desc");
	next if ($ret_code);

	# verifying the web entry_point info
	($ret_code, $null) = $conf_instance->get_value("entry_point");
	next if ($ret_code);

	my %tmp_hash;
	($ret_code, %tmp_hash) = $conf_instance->get_all();
	next if ($ret_code);
	
	foreach my $key (sort keys(%tmp_hash))
	{
	    $ret_hash->{$file} = %tmp_hash->{$key};
	    $ret_hash->{$file}->{'path'} = $file_path;
	    last;
	}
    }

    return (0, $ret_hash);
}

sub get_user_right
{
    my $user = shift;

    my ($log_ret, $log_instance) = Lib_Log::get_obj_instance();
    Lib_CGI::send_critical_header($log_instance) if ($log_ret);
    
    my ($ret_code, $conf_instance) = new INTLIQ::Conf($RIGHT_FILE, $log_instance);
    Lib_CGI::send_critical_header($conf_instance) if ($ret_code);

    my $rules_str;
    ($ret_code, $rules_str) = $conf_instance->get_value($user);
    return ($ret_code, $rules_str) if ($ret_code);

    my @ret_tab = split(" ", $rules_str);
    
    return (0, \@ret_tab);
}

sub set_user_right
{
    my ($user, @modules_tab) = @_;

    my ($log_ret, $log_instance) = Lib_Log::get_obj_instance();
    Lib_CGI::send_critical_header($log_instance) if ($log_ret);
    
    my ($ret_code, $conf_instance) = new INTLIQ::Conf($RIGHT_FILE, $log_instance);
    Lib_CGI::send_critical_header($conf_instance) if ($ret_code);

    my $modules_str = join(" ", @modules_tab);

    my $rules_str;
    ($ret_code, $rules_str) = $conf_instance->set_value($user, $modules_str);
    return ($ret_code, $rules_str) if ($ret_code);

    ($ret_code, $rules_str) = $conf_instance->save();
    return ($ret_code, $rules_str) if ($ret_code);

    return (0, 0);
}

sub delete_user_right
{
    my $user = shift;

    my ($log_ret, $log_instance) = Lib_Log::get_obj_instance();
    Lib_CGI::send_critical_header($log_instance) if ($log_ret);
    
    my ($ret_code, $conf_instance) = new INTLIQ::Conf($RIGHT_FILE, $log_instance);
    Lib_CGI::send_critical_header($conf_instance) if ($ret_code);

    my $rules_str;
    ($ret_code, $rules_str) = $conf_instance->delete_key($user);
    return ($ret_code, $rules_str) if ($ret_code);

    ($ret_code, $rules_str) = $conf_instance->save();
    return ($ret_code, $rules_str) if ($ret_code);
    
    return (0, 0);
}

sub is_executable
{
    my ($module_name, $entry_point) = @_;

    return (1) if (! -x "$MOD_DIR$module_name/$entry_point");
    return (0);
}

sub get_executable_cmd
{
    my ($module_name, $entry_point) = @_;

    return ("$MOD_DIR$module_name/$entry_point");
}

1;
