use Lib_TT;
use INTLIQ::Conf;
use Lib_Translation qw(Translate);
use Lib_Auth;
use Lib_Modules;

Lib_TT::new_tt("templates/global/", "templates/options/");
Lib_Translation::init("main.lang");

# Recuperation de l'utilisateur
my $user = Lib_CGI::session_get_param("user");

if ($user ne "admin")
{
    # si t'es pas admin, je fais vautrer wishmin :p
    Lib_CGI::send_critical_header("Someone is trying to do something bad !!");
}

####### Gestion du post
### Gestion de la langue..
if (Lib_CGI::get_param("input_lang"))
{
    # Si j'entre la c'est que l'utilisateur a clique sur l'input de langue
    my $new_lang = Lib_CGI::get_param("lang");

    my ($log_ret, $log_instance) = Lib_Log::get_obj_instance();
    Lib_CGI::send_critical_header($log_instance) if ($log_ret);

    my ($ret_code, $conf_instance) = new INTLIQ::Conf("etc/wishmin.conf", $log_instance);
    Lib_CGI::send_critical_header($conf_instance) if ($ret_code);

    my $value;
    ($ret_code, $value) = $conf_instance->get_value("lang");
    Lib_CGI::send_critical_header($value) if ($ret_code);

    if ($value ne $new_lang)
    {
	($ret_code, $value) = $conf_instance->set_value("lang", $new_lang);
	Lib_CGI::send_critical_header($value) if ($ret_code);

	($ret_code, $value) = $conf_instance->save();
	Lib_CGI::send_critical_header($value) if ($ret_code);

	# I have to reinit the translation lib..
	Lib_Translation::init("main.lang");
    }

    Lib_TT::set("success_msg", Translate("msg_translation_change"));
}

### Gestion de l'ajout d'un utilisateur
if (Lib_CGI::get_param("submit_new_user"))
{
    my $new_user = Lib_CGI::get_param("input_new_user_name");
    my $pass1 = Lib_CGI::get_param("input_new_user_pass1");
    my $pass2 = Lib_CGI::get_param("input_new_user_pass2");

    if (!$new_user) { Lib_TT::set("error_msg", Translate("msg_error_new_user_name_input_empty")); }
    elsif (!$pass1) { Lib_TT::set("error_msg", Translate("msg_error_new_user_pass1_input_empty")); }
    elsif (!$pass2) { Lib_TT::set("error_msg", Translate("msg_error_new_user_pass2_input_empty")); }
    elsif ($pass1 ne $pass2) { Lib_TT::set("error_msg", Translate("msg_error_new_user_pass_mismatch")); }
    elsif ($new_user =~ m/\W/) { Lib_TT::set("error_msg", Translate("msg_error_new_user_invalid_chars")); }
    else
    {
	my ($ret_code, $ret_msg) = Lib_Auth::check_user_being($new_user);
	Lib_CGI::send_critical_header($ret_msg) if ($ret_code && $ret_code != -1);
	
	if ($ret_code == -1)
	{
	    # User exists
	    Lib_TT::set("error_msg", Translate("msg_error_new_user_already_exists"));
	}
	else
	{
	    ($ret_code, $ret_msg) = Lib_Auth::insert_user($new_user, $pass1);
	    Lib_CGI::send_critical_header($ret_msg) if ($ret_code);

	    Lib_TT::set("success_msg", Translate("msg_error_new_user_creation_success"));
	}
    }
}

### Gestion de la suppression d'un utilisateur
if (Lib_CGI::get_param("submit_del_user"))
{
    my $user = Lib_CGI::get_param("user_del_select");

    if (!$user) { Lib_TT::set("error_msg", Translate("msg_error_del_user_name_input_empty")); }
    elsif ($user =~ m/\W/) { Lib_TT::set("error_msg", Translate("msg_error_del_user_invalid_chars")); }
    elsif ($user eq "admin")  { Lib_TT::set("error_msg", Translate("msg_error_del_user_is_admin")); }
    else
    {
	my ($ret_code, $ret_msg) = Lib_Auth::check_user_being($user);
	Lib_CGI::send_critical_header($ret_msg) if ($ret_code && $ret_code != -1);
	
	if ($ret_code == -1)
	{
	    # User exists
 	    ($ret_code, $ret_msg) = Lib_Auth::delete_user($user);
 	    Lib_CGI::send_critical_header($ret_msg) if ($ret_code);

	    my ($err_modules, $str_modules) = Lib_Modules::delete_user_right($user);
	    Lib_CGI::send_critical_header($str_modules) if ($err_modules);

	    Lib_TT::set("success_msg", Translate("msg_error_del_user_deletion_success"));
	}
	else
	{
	    Lib_TT::set("error_msg", Translate("msg_error_del_user_not_found"));
	}
    }
}

### Gestion des droits des utilisateurs sur les modules..
if (Lib_CGI::get_param("submit_user_rules"))
{
    my ($err, $user_list) = Lib_Auth::get_user_list();
    Lib_CGI::send_critical_header($user_list) if ($err);
    
    foreach my $user (@$user_list)
    {
	next if ($user eq "admin");
	if (Lib_CGI::get_param($user))
	{
	    my ($err_modules, $str_modules) = Lib_Modules::set_user_right($user, Lib_CGI::get_param($user));
	    Lib_CGI::send_critical_header($str_modules) if ($err_modules);
	}
    }
    Lib_TT::set("success_msg", Translate("msg_user_rules_success"));
}


########## Go goldorak, Go !!

Lib_TT::set("link_back", Translate("link_back"));
Lib_TT::set("link_logout", Translate("link_logout"));

Lib_TT::set("page_title", Translate("option_page_title"));

### Gestion de la langue..
# Definition de la hash pour le select de la langue
my $lang_hash = {};
$lang_hash->{'lang_list'} = Lib_Translation::get_supported_languages();
$lang_hash->{'lang_selected'} = Lib_Translation::get_current_lang();
$lang_hash->{'name'} = "lang";

Lib_TT::set("lang_select_hash", $lang_hash);

# Definition de la hash pour le bouton de validation de la langue
my $lang_input_hash = {};
$lang_input_hash->{'name'} = "input_lang";
$lang_input_hash->{'value'} = Translate("button_apply");

Lib_TT::set("lang_input_hash", $lang_input_hash);
Lib_TT::set("lang_box_title", Translate("msg_title_box_language"));


### Gestion de l'ajout d'un utilisateur
# Definition de la hash pour l'input du nom
my $new_user_name_input_hash = {};
$new_user_name_input_hash->{'name'} = "input_new_user_name";
Lib_TT::set("new_user_name_input_hash", $new_user_name_input_hash);
Lib_TT::set("new_user_name_label", Translate("msg_new_user_name_input"));

# Definition de la hash pour l'input du pass
my $new_user_pass1_input_hash = {};
$new_user_pass1_input_hash->{'name'} = "input_new_user_pass1";
Lib_TT::set("new_user_pass1_input_hash", $new_user_pass1_input_hash);
Lib_TT::set("new_user_pass1_label", Translate("msg_new_user_pass1_input"));

# Definition de la hash pour l'input du pass de confirmation
my $new_user_pass2_input_hash = {};
$new_user_pass2_input_hash->{'name'} = "input_new_user_pass2";
Lib_TT::set("new_user_pass2_input_hash", $new_user_pass2_input_hash);
Lib_TT::set("new_user_pass2_label", Translate("msg_new_user_pass2_input"));

# Definition de la hash pour la validation du formulaire
my $new_user_submit_hash = {};
$new_user_submit_hash->{'name'} = "submit_new_user";
$new_user_submit_hash->{'value'} = Translate("button_apply");

Lib_TT::set("new_user_submit_hash", $new_user_submit_hash);

Lib_TT::set("new_user_box_title", Translate("msg_title_box_create"));

### Gestion de la suppression d'un utilisateur
# Definition de la hash pour le select de la langue
my ($err, $user_list) = Lib_Auth::get_user_list();
Lib_CGI::send_critical_header($user_list) if ($err);

my $user_del_select_hash = {};
my @tmp_user_list = grep(!/^admin$/, @$user_list);
$user_del_select_hash->{'user_list'} = \@tmp_user_list;
$user_del_select_hash->{'name'} = "user_del_select";

Lib_TT::set("user_del_select_hash", $user_del_select_hash);

# Definition de la hash pour le bouton de validation de la langue
my $user_del_submit_hash = {};
$user_del_submit_hash->{'name'} = "submit_del_user";
$user_del_submit_hash->{'value'} = Translate("button_apply");

Lib_TT::set("user_del_submit_hash", $user_del_submit_hash);

Lib_TT::set("del_user_box_title", Translate("msg_title_box_deluser"));
Lib_TT::set("change_passwd_box_title", Translate("msg_title_box_change_passwd"));

### Gestion des droits des utilisateurs sur les modules..
my $user_rules_hash = {};

($err, $user_list) = Lib_Auth::get_user_list();
Lib_CGI::send_critical_header($user_list) if ($err);

my ($err_modules, $modules_hash) = Lib_Modules::list_modules();
Lib_CGI::send_critical_header($modules_hash) if ($err_modules);

Lib_TT::set("access_right_box_title", Translate("msg_title_box_access"));

# Je contruis une hash contenant les cases coches ou non 
# en fonction des modules...
foreach my $user (@$user_list)
{
    my $user_right;

    ($err_modules, $user_right) = Lib_Modules::get_user_right($user)
	if ($user ne "admin");

    foreach my $module (sort keys(%{$modules_hash}))
    {
	if ($user eq "admin")
	{
	    $user_rules_hash->{$user}->{$module}->{'selected'} = 1;
	    $user_rules_hash->{$user}->{$module}->{'selectable'} = 0;
	}
	else
	{
	    $user_rules_hash->{$user}->{$module}->{'selected'} = 0;
	    $user_rules_hash->{$user}->{$module}->{'selected'} = 1
		if (grep(/^$module$/, @$user_right));
	    $user_rules_hash->{$user}->{$module}->{'selectable'} = 1;
	}
    }
}

# Je contruis un tableau contenant des hash avec les
# noms des modules pour le tableau
my $modules_tab = ();
foreach my $module (sort keys(%{$modules_hash}))
{
    my $tmp_hash = {};
    $tmp_hash->{'name'} = $module;
    $tmp_hash->{'desc'} = $modules_hash->{$module}->{'desc'};
    push(@$modules_tab, $tmp_hash);
}

Lib_TT::set("user_rules_checkbox_hash", $user_rules_hash);
Lib_TT::set("user_rules_modules_tab", $modules_tab);

# Definition de la hash pour le bouton de validation des regles
my $user_rules_submit_hash = {};
$user_rules_submit_hash->{'name'} = "submit_user_rules";
$user_rules_submit_hash->{'value'} = Translate("button_apply");

Lib_TT::set("user_rules_submit_hash", $user_rules_submit_hash);

Lib_CGI::print_html_header();
Lib_TT::process("options.tt");


# Lib_CGI::debug();
# Lib_TT::debug();

1;
